# Django Improved Permissions

[![Coverage Status](https://coveralls.io/repos/github/s-sys/django-improved-permissions/badge.svg?branch=master)](https://coveralls.io/github/s-sys/django-improved-permissions?branch=master)
[![Build Status](https://travis-ci.org/s-sys/django-improved-permissions.svg?branch=master)](https://travis-ci.org/s-sys/django-improved-permissions)
[![Documentation Status](https://readthedocs.org/projects/django-improved-permissions/badge/?version=latest)](http://django-improved-permissions.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/django-improved-permissions.svg)](https://badge.fury.io/py/django-improved-permissions)

Django Improved Permissions (DIP) is a django application made to make django's default permission system more robust. Here are some highlights:

* Object-level Permissions
* Role Assignment
* Permissions Inheritance
* Cache
* Customizable Permissions per User Instance

## Documentation

The full documentation is available in our page in Read the Docs.

http://django-improved-permissions.readthedocs.io/en/latest/

## Contributing

Feel free to create new issues if you have suggestions or find some bugs.

## Commercial Support

This project is used in products of SSYS clients.

We are always looking for exciting work, so if you need any commercial support, feel free to get in touch: contato@ssys.com.br
